package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Die(format string, args ...interface{})
Die prints an error and exits.
FormatAmount colorizes a balance amount string.
JSON prints any value as formatted JSON.
Table prints a nicely formatted table to stdout.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.